


### <a name="manual"></a> Image block

Inserts an image.

| Key       |      Description      | Default |
|:----------|:--------------------- | :----- |
| type      |  image                 |  
| filename  |  relative filepath to image file        |
| caption   |  (optional) caption under the image                 |  
| width     |  (optional) width of image in cm        | width of current document |
| align     |  (optional) alignment of image        | CENTER |
| padding   |  (optional) padding of image        | 10 |

Example:
```YAML
- type     : image
  width    : 5.6
  filename : /img/test.png
```

Back to [Documentation](../../../README.md#block_external)
